<?php
/*
YaotGui Directory


This file is part of YaotGui.

YaotGui is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

YaotGui is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with YaotGui.  If not, see <http://www.gnu.org/licenses/>.

Copyright 2008 Thomas Axelsson

*/

/// Gets directory contents and stores it for easy access
/** The directory content is never read until getFiles or getDirectories is called.
 */
class LibDirectory
{
   var $_files; # = array();
   var $_directories; # = array();
   var $_path;
   var $_filePRegFilter;
   var $_loaded = false;

   /// Creates a new Directory instance
   /** The content of $path will be used if neither $dirs nor $files is specified.
       \param $path The physical directory path
       \param $filePRegFilter An optional Perl regular expression to filter the files.
              See Settings::IMAGE_FILTER and Settings::VIDEO_FILTER
       \param $dirs An optional Directory array of directories
       \param $files An optional string array of files
    */
   function __construct($path, $filePRegFilter = NULL, $dirs = NULL, $files = NULL)
   {
      $this->_path = $path;
      $this->_directories = $dirs;
      $this->_files = $files;
      $this->_filePRegFilter = $filePRegFilter;

      $this->_loaded = ($dirs != NULL || $files != NULL);
   }

   private function GetDirectory()
   {
      $this->_directories = array();
      $this->_files = array();

      //make sure we are allowed to show this
      if(!isInAllowedPath($this->_path))
      {
	 $this->_loaded = true;
	 return;
      }

      if(file_exists($this->_path) && $handle = openDir($this->_path))
      {
	 while(($item = readdir($handle)) !== false)
	 {
	    if(is_dir("$this->_path/$item"))
	    {
	       if($item != '..' && $item != '.')
	       {
		  $this->_directories[] = new LibDirectory("$this->_path/$item", $this->_filePRegFilter);
	       }
	    }
	    else if($this->_filePRegFilter == NULL || preg_match($this->_filePRegFilter, $item))
	    {
	       $this->_files[] = $item;
	    }
	 }
	 
	 closedir($handle);
      }

      $this->_loaded = true;
   }

   function getPath()
   {
      return $this->_path;
   }

   function getParentPath()
   {
      return dirname($this->_path);
   }

   function getName()
   {
      return basename($this->_path);
   }

   function getDirectories()
   {
      if(!$this->_loaded)
      {
	 $this->GetDirectory();
      }
      return $this->_directories;
   }

   function getFiles()
   {
      if(!$this->_loaded)
      {
	 $this->GetDirectory();
      }
      return $this->_files;
   }
}

?>
