<?php
/*
YaotGui Directory Lists


This file is part of YaotGui.

YaotGui is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

YaotGui is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with YaotGui.  If not, see <http://www.gnu.org/licenses/>.

Copyright 2008 Thomas Axelsson

*/

class LibDirectoryList extends LibList
{
   public $_directory;

   function __construct($id, $class, $directory, $upItem = '<Up>')
   {
      parent::__construct($id, $class);
      $this->_directory = $directory;
      $this->_type = 'LibDirectoryList';

      //add "up" item
      if($upItem != NULL)
      {
	 parent::addItem(array('type' => 'dir', 'path' => $directory->getParentPath(), 'text' => $upItem), $upItem);
      }
      $dirs = &$directory->getDirectories();
      foreach($dirs as &$dir)
      {
	 parent::addItem(array('type' => 'dir', 'path' => $dir->getPath(), 'text' => $dir->getName()), $dir->getName());
      }
      $files = &$directory->getFiles();
      foreach($files as &$file)
      {
	 parent::addItem(array('type' => 'file', 'path' => $file, 'text' => $file), $file);
      }
   }

   function getDirectory()
   {
      return $this->_directory;
   }

   static private function compare(&$item1, &$item2)
   {
      if($item1->getValue('type') == $item2->getValue('type'))
	 return strcoll($item1->getText(), $item2->getText());
      else
	 return ($item1->getValue('type') == 'dir' ? -1 : 1);
   }

   function sort()
   {
      usort($this->_items, array("LibListItem", "compare"));
   }
}

class LibDirectoryImageList extends LibImageList
{
   public $_directory;

   function __construct($id, $class, $columnCount, $imgWidth, $imgHeight, $directory, $dirImg = NULL, $fileImg = NULL, $useFileAsOwnImage = false, $upItemImg = NULL, $upItem = '<Up>')
   {
      parent::__construct($id, $class, $columnCount, $imgWidth, $imgHeight);
      $this->_directory = $directory;
      $this->_type = 'LibDirectoryImageList';

      //add "up" item
      if($upItem != NULL)
      {
	 parent::addItem(array('type' => 'dir', 'path' => $directory->getParentPath(), 'text' => $upItem), $upItem, $upItemImg, false);
      }
      $dirs = &$directory->getDirectories();
      foreach($dirs as &$dir)
      {
	 parent::addItem(array('type' => 'dir', 'path' => $dir->getPath(), 'text' => $dir->getName()), $dir->getName(), $dirImg, false);
      }
      $files = &$directory->getFiles();
      $dir = &$directory->getPath();
      foreach($files as &$file)
      {
	 if($useFileAsOwnImage)
	 {
	    parent::addItem(array('type' => 'file', 'path' => "$dir/$file", 'text' => $file), $file, "$dir/$file", true);
	 }
	 else
	 {
	    parent::addItem(array('type' => 'file', 'path' => "$dir/$file", 'text' => $file), $file, $fileImg, false);
	 }
      }
   }

   function getDirectory()
   {
      return $this->_directory;
   }

   static function compareItems(&$item1, &$item2)
   {
      if($item1->getValue('type') == $item2->getValue('type'))
	 return strcoll($item1->getText(), $item2->getText());
      else
	 return ($item1->getValue('type') == 'dir' ? -1 : 1);
   }

   function sort()
   {
      usort($this->_items, array("LibDirectoryImageList", "compareItems"));
   }
}
?>
